PlotFractions: PlotFractions: Visualize Fraction Proportions

View source: R/fracfixr.r

PlotFractionsR Documentation

PlotFractions: Visualize Fraction Proportions

Description

Creates a stacked bar plot showing the distribution of RNA across fractions for each replicate, including the "lost" fraction.

Usage

PlotFractions(FracFixed)

Arguments

FracFixed

Output from FracFixR() function

Value

ggplot2 object showing fraction proportions

Examples

data(example_counts)
data(example_annotation)

# Run FracFixR
results <- FracFixR(example_counts, example_annotation, parallel=FALSE)
# Create fraction plot
frac_plot <- PlotFractions(results)
# Save plot with ggsave("fractions.pdf", frac_plot, width = 10, height = 8)


FracFixR documentation built on May 11, 2026, 9:09 a.m.