| beta_binomial_wald | R Documentation |
Implements Wald test using beta-binomial distribution to account for overdispersion in count data. Useful when variance exceeds that expected under binomial distribution.
beta_binomial_wald(counts, successes, annotation)
counts |
Total count matrix |
successes |
Success count matrix (not proportions) |
annotation |
Sample metadata |
Data frame with test results for all transcripts
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.