| run_glm | R Documentation |
Fits a binomial generalized linear model to test for differential proportions between conditions for a single transcript.
run_glm(transcript, counts, successes, sample_info)
transcript |
Transcript identifier |
counts |
Total count matrix |
successes |
Proportion matrix |
sample_info |
Sample metadata with Condition factor |
Data frame with test results for this transcript
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.