| PlotFractions | R Documentation |
Creates a stacked bar plot showing the distribution of RNA across fractions for each replicate, including the "lost" fraction.
PlotFractions(FracFixed)
FracFixed |
Output from FracFixR() function |
ggplot2 object showing fraction proportions
data(example_counts)
data(example_annotation)
# Run FracFixR
results <- FracFixR(example_counts, example_annotation, parallel=FALSE)
# Create fraction plot
frac_plot <- PlotFractions(results)
# Save plot with ggsave("fractions.pdf", frac_plot, width = 10, height = 8)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.